@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Keychain;
@@ -17,19 +21,13 @@ use OCP\EventDispatcher\Event;
  */
 class GenericKeychainEvent extends Event {
 
-    /**
-     * @var Keychain
-     */
-    protected Keychain $Keychain;
-
     /**
      * GenericKeychainEvent constructor.
      *
      * @param Keychain $Keychain
      */
-    public function __construct(Keychain $Keychain) {
+    public function __construct(protected Keychain $Keychain) {
         parent::__construct();
-        $this->Keychain = $Keychain;
     }
 
     /**
