@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Password;
@@ -17,19 +21,13 @@ use OCP\EventDispatcher\Event;
  */
 class GenericPasswordEvent extends Event {
 
-    /**
-     * @var Password
-     */
-    protected Password $password;
-
     /**
      * GenericPasswordEvent constructor.
      *
      * @param Password $password
      */
-    public function __construct(Password $password) {
+    public function __construct(protected Password $password) {
         parent::__construct();
-        $this->password = $password;
     }
 
     /**
