@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\TagRevision;
@@ -17,21 +21,6 @@ use OCP\EventDispatcher\Event;
  */
 class BeforeTagRevisionClonedEvent extends Event {
 
-    /**
-     * @var TagRevision
-     */
-    protected TagRevision $original;
-
-    /**
-     * @var TagRevision
-     */
-    protected TagRevision $clone;
-
-    /**
-     * @var array
-     */
-    protected array       $overwrites;
-
     /**
      * BeforeTagRevisionClonedEvent constructor.
      *
@@ -39,11 +28,8 @@ class BeforeTagRevisionClonedEvent extends Event {
      * @param TagRevision $clone
      * @param array       $overwrites
      */
-    public function __construct(TagRevision $original, TagRevision $clone, array $overwrites) {
+    public function __construct(protected TagRevision $original, protected TagRevision $clone, protected array $overwrites) {
         parent::__construct();
-        $this->original = $original;
-        $this->clone = $clone;
-        $this->overwrites = $overwrites;
     }
 
     /**
