@@ -11,9 +11,10 @@
 
 namespace OCA\Passwords\Exception\Image\Imaginary;
 
+use Exception;
 use Throwable;
 
-class ImaginaryCommunicationException extends \Exception {
+class ImaginaryCommunicationException extends Exception {
 
     const EXCEPTION_CODE = 0;
 
@@ -22,7 +23,7 @@ class ImaginaryCommunicationException extends \Exception {
      *
      * @param Throwable|null $previous
      */
-    public function __construct(string $message, Throwable $previous = null) {
+    public function __construct(string $message, ?Throwable $previous = null) {
         parent::__construct($message, static::EXCEPTION_CODE, $previous);
     }
 }
\ No newline at end of file
